summaryrefslogtreecommitdiffstats
path: root/kjsembed/qtbindings/qcanvaspixmaparray_imp.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kjsembed/qtbindings/qcanvaspixmaparray_imp.cpp')
-rw-r--r--kjsembed/qtbindings/qcanvaspixmaparray_imp.cpp76
1 files changed, 38 insertions, 38 deletions
diff --git a/kjsembed/qtbindings/qcanvaspixmaparray_imp.cpp b/kjsembed/qtbindings/qcanvaspixmaparray_imp.cpp
index dbb41a18..d3f249d9 100644
--- a/kjsembed/qtbindings/qcanvaspixmaparray_imp.cpp
+++ b/kjsembed/qtbindings/qcanvaspixmaparray_imp.cpp
@@ -1,12 +1,12 @@
-#include <qcstring.h>
-#include <qimage.h>
-#include <qpainter.h>
-#include <qpalette.h>
-#include <qpixmap.h>
-#include <qfont.h>
+#include <tqcstring.h>
+#include <tqimage.h>
+#include <tqpainter.h>
+#include <tqpalette.h>
+#include <tqpixmap.h>
+#include <tqfont.h>
#include <kjs/object.h>
@@ -15,7 +15,7 @@
#include <kjsembed/jsopaqueproxy.h>
#include <kjsembed/jsbinding.h>
-#include <qcanvas.h>
+#include <tqcanvas.h>
#include "qcanvaspixmaparray_imp.h"
/**
@@ -43,7 +43,7 @@ void QCanvasPixmapArrayImp::addStaticBindings( KJS::ExecState *exec, KJS::Object
};
int idx = 0;
- QCString lastName;
+ TQCString lastName;
while( methods[idx].name ) {
if ( lastName != methods[idx].name ) {
@@ -74,7 +74,7 @@ void QCanvasPixmapArrayImp::addBindings( KJS::ExecState *exec, KJS::Object &obje
};
int idx = 0;
- QCString lastName;
+ TQCString lastName;
while( methods[idx].name ) {
if ( lastName != methods[idx].name ) {
@@ -87,25 +87,25 @@ void QCanvasPixmapArrayImp::addBindings( KJS::ExecState *exec, KJS::Object &obje
}
/**
* Extract a QCanvasPixmapArray pointer from an Object.
*/
-QCanvasPixmapArray *QCanvasPixmapArrayImp::toQCanvasPixmapArray( KJS::Object &self )
+TQCanvasPixmapArray *QCanvasPixmapArrayImp::toQCanvasPixmapArray( KJS::Object &self )
{
JSObjectProxy *ob = JSProxy::toObjectProxy( self.imp() );
if ( ob ) {
- QObject *obj = ob->object();
+ TQObject *obj = ob->object();
if ( obj )
- return dynamic_cast<QCanvasPixmapArray *>( obj );
+ return dynamic_cast<TQCanvasPixmapArray *>( obj );
}
JSOpaqueProxy *op = JSProxy::toOpaqueProxy( self.imp() );
if ( !op )
return 0;
- if ( op->typeName() != "QCanvasPixmapArray" )
+ if ( op->typeName() != "TQCanvasPixmapArray" )
return 0;
- return op->toNative<QCanvasPixmapArray>();
+ return op->toNative<TQCanvasPixmapArray>();
}
/**
@@ -135,7 +135,7 @@ KJS::Object QCanvasPixmapArrayImp::construct( KJS::ExecState *exec, const KJS::L
break;
}
- QString msg = i18n("QCanvasPixmapArrayCons has no constructor with id '%1'.").arg(id);
+ TQString msg = i18n("QCanvasPixmapArrayCons has no constructor with id '%1'.").arg(id);
return throwError(exec, msg,KJS::ReferenceError);
}
@@ -144,9 +144,9 @@ KJS::Object QCanvasPixmapArrayImp::QCanvasPixmapArray_1( KJS::ExecState *exec, c
{
- // We should now create an instance of the QCanvasPixmapArray object
+ // We should now create an instance of the TQCanvasPixmapArray object
- QCanvasPixmapArray *ret = new QCanvasPixmapArray(
+ TQCanvasPixmapArray *ret = new TQCanvasPixmapArray(
);
return KJS::Object();
@@ -155,14 +155,14 @@ KJS::Object QCanvasPixmapArrayImp::QCanvasPixmapArray_1( KJS::ExecState *exec, c
KJS::Object QCanvasPixmapArrayImp::QCanvasPixmapArray_2( KJS::ExecState *exec, const KJS::List &args )
{
- QString arg0 = extractQString(exec, args, 0);
+ TQString arg0 = extractQString(exec, args, 0);
int arg1 = extractInt(exec, args, 1);
- // We should now create an instance of the QCanvasPixmapArray object
+ // We should now create an instance of the TQCanvasPixmapArray object
- QCanvasPixmapArray *ret = new QCanvasPixmapArray(
+ TQCanvasPixmapArray *ret = new TQCanvasPixmapArray(
arg0,
arg1 );
@@ -173,20 +173,20 @@ KJS::Object QCanvasPixmapArrayImp::QCanvasPixmapArray_2( KJS::ExecState *exec, c
KJS::Object QCanvasPixmapArrayImp::QCanvasPixmapArray_3( KJS::ExecState *exec, const KJS::List &args )
{
// Unsupported parameter QPtrList< QPixmap >
return KJS::Object();
- QPtrList< QPixmap > arg0; // Dummy
+ TQPtrList< TQPixmap > arg0; // Dummy
- // Unsupported parameter QPtrList< QPoint >
+ // Unsupported parameter TQPtrList< TQPoint >
return KJS::Object();
- QPtrList< QPoint > arg1; // Dummy
+ TQPtrList< TQPoint > arg1; // Dummy
- // We should now create an instance of the QCanvasPixmapArray object
+ // We should now create an instance of the TQCanvasPixmapArray object
- QCanvasPixmapArray *ret = new QCanvasPixmapArray(
+ TQCanvasPixmapArray *ret = new TQCanvasPixmapArray(
arg0,
arg1 );
@@ -197,20 +197,20 @@ KJS::Object QCanvasPixmapArrayImp::QCanvasPixmapArray_3( KJS::ExecState *exec, c
KJS::Object QCanvasPixmapArrayImp::QCanvasPixmapArray_4( KJS::ExecState *exec, const KJS::List &args )
{
// Unsupported parameter QValueList< QPixmap >
return KJS::Object();
- QValueList< QPixmap > arg0; // Dummy
+ TQValueList< TQPixmap > arg0; // Dummy
// Unsupported parameter QPointArray
return KJS::Object();
- QPointArray arg1; // Dummy
+ TQPointArray arg1; // Dummy
- // We should now create an instance of the QCanvasPixmapArray object
+ // We should now create an instance of the TQCanvasPixmapArray object
- QCanvasPixmapArray *ret = new QCanvasPixmapArray(
+ TQCanvasPixmapArray *ret = new TQCanvasPixmapArray(
arg0,
arg1 );
@@ -252,7 +252,7 @@ KJS::Value QCanvasPixmapArrayImp::call( KJS::ExecState *exec, KJS::Object &self,
break;
}
- QString msg = i18n( "QCanvasPixmapArrayImp has no method with id '%1'." ).arg( id );
+ TQString msg = i18n( "QCanvasPixmapArrayImp has no method with id '%1'." ).arg( id );
return throwError(exec, msg,KJS::ReferenceError);
}
@@ -260,7 +260,7 @@ KJS::Value QCanvasPixmapArrayImp::call( KJS::ExecState *exec, KJS::Object &self,
KJS::Value QCanvasPixmapArrayImp::readPixmaps_6( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- QString arg0 = extractQString(exec, args, 0);
+ TQString arg0 = extractQString(exec, args, 0);
int arg1 = extractInt(exec, args, 1);
@@ -275,7 +275,7 @@ KJS::Value QCanvasPixmapArrayImp::readPixmaps_6( KJS::ExecState *exec, KJS::Obje
KJS::Value QCanvasPixmapArrayImp::readCollisionMasks_7( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- QString arg0 = extractQString(exec, args, 0);
+ TQString arg0 = extractQString(exec, args, 0);
bool ret;
ret = instance->readCollisionMasks(
@@ -300,7 +300,7 @@ KJS::Value QCanvasPixmapArrayImp::image_10( KJS::ExecState *exec, KJS::Object &o
instance->image(
arg0 );
- return KJS::Value(); // Returns 'QCanvasPixmap *'
+ return KJS::Value(); // Returns 'TQCanvasPixmap *'
}
@@ -309,10 +309,10 @@ KJS::Value QCanvasPixmapArrayImp::setImage_11( KJS::ExecState *exec, KJS::Object
int arg0 = extractInt(exec, args, 0);
// Unsupported parameter QCanvasPixmap *
return KJS::Value();
- QCanvasPixmap * arg1; // Dummy
+ TQCanvasPixmap * arg1; // Dummy
instance->setImage(
arg0,
@@ -87,25 +87,25 @@ void QCanvasPixmapArrayImp::addBindings( KJS::ExecState *exec, KJS::Object &obje
}
/**
- * Extract a QCanvasPixmapArray pointer from an Object.
+ * Extract a TQCanvasPixmapArray pointer from an Object.
*/
@@ -173,20 +173,20 @@ KJS::Object QCanvasPixmapArrayImp::QCanvasPixmapArray_2( KJS::ExecState *exec, c
KJS::Object QCanvasPixmapArrayImp::QCanvasPixmapArray_3( KJS::ExecState *exec, const KJS::List &args )
{
- // Unsupported parameter QPtrList< QPixmap >
+ // Unsupported parameter TQPtrList< TQPixmap >
return KJS::Object();
@@ -197,20 +197,20 @@ KJS::Object QCanvasPixmapArrayImp::QCanvasPixmapArray_3( KJS::ExecState *exec, c
KJS::Object QCanvasPixmapArrayImp::QCanvasPixmapArray_4( KJS::ExecState *exec, const KJS::List &args )
{
- // Unsupported parameter QValueList< QPixmap >
+ // Unsupported parameter TQValueList< TQPixmap >
return KJS::Object();
@@ -309,10 +309,10 @@ KJS::Value QCanvasPixmapArrayImp::setImage_11( KJS::ExecState *exec, KJS::Object
int arg0 = extractInt(exec, args, 0);
- // Unsupported parameter QCanvasPixmap *
+ // Unsupported parameter TQCanvasPixmap *
return KJS::Value();